summaryrefslogtreecommitdiff
path: root/apps/plugins
diff options
context:
space:
mode:
authorHristo Kovachev <bger@rockbox.org>2006-03-21 15:24:25 +0000
committerHristo Kovachev <bger@rockbox.org>2006-03-21 15:24:25 +0000
commit5a0bb990131f56bce9e7188bd1c109f7058b8df5 (patch)
treefec1d79e1db6a83c9d09aa299588e37556570971 /apps/plugins
parent1c1915c0d120947ca04ae76e42dc513648a7ffa4 (diff)
Jewels: little changes regarding trademark issues
Brickmania: change the highscore file to the more apropriate "brickmania.score" (patch #4789 by Mikael Magnusson) git-svn-id: svn://svn.rockbox.org/rockbox/trunk@9169 a1c6a512-1295-4272-9138-f99709370657
Diffstat (limited to 'apps/plugins')
-rw-r--r--apps/plugins/brickmania.c2
-rw-r--r--apps/plugins/jewels.c8
2 files changed, 5 insertions, 5 deletions
diff --git a/apps/plugins/brickmania.c b/apps/plugins/brickmania.c
index 75f7e3422d..3cf6a48fef 100644
--- a/apps/plugins/brickmania.c
+++ b/apps/plugins/brickmania.c
@@ -775,7 +775,7 @@ void sleep (int secs)
}
-#define HIGH_SCORE "highscore.cfg"
+#define HIGH_SCORE "brickmania.score"
#define MENU_LENGTH 4
int game_menu(int when)
{
diff --git a/apps/plugins/jewels.c b/apps/plugins/jewels.c
index a385466f82..adae1765e8 100644
--- a/apps/plugins/jewels.c
+++ b/apps/plugins/jewels.c
@@ -926,7 +926,7 @@ static unsigned int jewels_nextlevel(struct game_context* bj) {
}
/*****************************************************************************
* bejeweld_recordscore() inserts a high score into the high scores list and
* returns the high score position.
******************************************************************************/
static int jewels_recordscore(struct game_context* bj) {
@@ -1048,9 +1048,9 @@ static void jewels_callback(void* param) {
}
/*****************************************************************************
* bejeweled() is the main game subroutine, it returns the final game status.
******************************************************************************/
-static int bejeweled(struct game_context* bj) {
+static int jewels_main(struct game_context* bj) {
int i, j;
int w, h;
int button;
@@ -1432,7 +1432,7 @@ enum plugin_status plugin_start(struct plugin_api* api, void* parameter) {
jewels_setcolors();
while(!exit) {
- switch(bejeweled(&bj)){
+ switch(jewels_main(&bj)){
case BJ_LOSE:
rb->splash(HZ*2, true, "No more moves!");
/* fall through to BJ_END */
@@ -926,7 +926,7 @@ static unsigned int jewels_nextlevel(struct game_context* bj) {
}
/*****************************************************************************
-* bejeweld_recordscore() inserts a high score into the high scores list and
+* jewels_recordscore() inserts a high score into the high scores list and
* returns the high score position.
******************************************************************************/
@@ -1048,9 +1048,9 @@ static void jewels_callback(void* param) {
}
/*****************************************************************************
-* bejeweled() is the main game subroutine, it returns the final game status.
+* jewels_main() is the main game subroutine, it returns the final game status.
******************************************************************************/